Stan Math Library: stan/math/prim/scal/meta/is_vector.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_vector.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_IS_VECTOR_HPP
2 #define STAN_MATH_PRIM_SCAL_META_IS_VECTOR_HPP
3
4 namespace stan {
5
6 // FIXME: use boost::type_traits::remove_all_extents to
7 // extend to array/ptr types
8
9 template <typename T>
10 struct is_vector {
11 enum { value = 0 };
12 typedef T type;
13 };
14 }
15 #endif
16
stan::is_vector::type
T type
Definition: is_vector.hpp:12
stan
Definition: log_sum_exp.hpp:8
stan::is_vector
Definition: is_vector.hpp:10
stan::is_vector::value
Definition: is_vector.hpp:11

[ Stan Home Page ] © 2011–2016, Stan Development Team.